==> ejc-dxcheck-impl-3.0.0-20240604.082143-20-sources.jar: com/ejianc/business/dxcheck/model/vo/UserVO.java <==
package com.ejianc.business.dxcheck.model.vo;/*author Wyx*/

import cn.hutool.core.date.DateTime;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Getter;
import java.util.Date;

public class UserVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer serialNum;//序号
    private String assessmentUnitCode;//考核单/部门Code
    private String assessmentUnitName;//考核单位/部门名称
    private String assessorJobNum;//考核人员工号
    private String assessorName;//考核人员

    private String assessorPhone;//考核人员电话
    private String leaderInfoDepartmentName;//信息化部门领导
    private String leaderInfoDepartmentNum;//信息化部门领导工号

    private String leaderInfoDepartmentPhone;//信息化部门领导电话
    private String leaderProjectManagementName;//项目分管领导
    private String leaderProjectManagementNum;//项目分管领导工号

    private String leaderProjectManagementPhone;//项目分管领导电话
    private String leaderUnitResponseNum;//单位负责人领导工号
    private String leaderUnitResponseName;//单位负责领导

    private String leaderUnitResponsePhone;//单位负责人领导电话
    private String modifierJobNum;//修改人工号
    private String modifierName;//修改人

    private String modifierPhone;//修改人电话
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date modifyTime;//修改时间
    public void setAssessorPhone(String assessorPhone) {
        this.assessorPhone = assessorPhone;
    }

    public String getAssessorPhone() {
        return assessorPhone;
    }

    public String getLeaderInfoDepartmentPhone() {
        return leaderInfoDepartmentPhone;
    }

    public void setLeaderInfoDepartmentPhone(String leaderInfoDepartmentPhone) {
        this.leaderInfoDepartmentPhone = leaderInfoDepartmentPhone;
    }

    public String getLeaderProjectManagementPhone() {
        return leaderProjectManagementPhone;
    }

    public void setLeaderProjectManagementPhone(String leaderProjectManagementPhone) {
        this.leaderProjectManagementPhone = leaderProjectManagementPhone;
    }

    public String getLeaderUnitResponsePhone() {
        return leaderUnitResponsePhone;
    }

    public void setLeaderUnitResponsePhone(String leaderUnitResponsePhone) {
        this.leaderUnitResponsePhone = leaderUnitResponsePhone;
    }

    public String getModifierPhone() {
        return modifierPhone;
    }

    public void setModifierPhone(String modifierPhone) {
        this.modifierPhone = modifierPhone;
    }


    public Integer getSerialNum() {
        return serialNum;
    }

    public void setSerialNum(Integer serialNum) {
        this.serialNum = serialNum;
    }

    public String getAssessmentUnitCode() {
        return assessmentUnitCode;
    }

    public void setAssessmentUnitCode(String assessmentUnitCode) {
        this.assessmentUnitCode = assessmentUnitCode;
    }

    public String getAssessmentUnitName() {
        return assessmentUnitName;
    }

    public void setAssessmentUnitName(String assessmentUnitName) {
        this.assessmentUnitName = assessmentUnitName;
    }

    public String getAssessorJobNum() {
        return assessorJobNum;
    }

    public void setAssessorJobNum(String assessorJobNum) {
        this.assessorJobNum = assessorJobNum;
    }
    public String getAssessorName() {
        return assessorName;
    }

    public void setAssessorName(String assessorName) {
        this.assessorName = assessorName;
    }

    public String getLeaderInfoDepartmentName() {
        return leaderInfoDepartmentName;
    }

    public void setLeaderInfoDepartmentName(String leaderInfoDepartmentName) {
        this.leaderInfoDepartmentName = leaderInfoDepartmentName;
    }

    public String getLeaderInfoDepartmentNum() {
        return leaderInfoDepartmentNum;
    }

    public void setLeaderInfoDepartmentNum(String leaderInfoDepartmentNum) {
        this.leaderInfoDepartmentNum = leaderInfoDepartmentNum;
    }

    public String getLeaderProjectManagementName() {
        return leaderProjectManagementName;
    }

    public void setLeaderProjectManagementName(String leaderProjectManagementName) {
        this.leaderProjectManagementName = leaderProjectManagementName;
    }

    public String getLeaderProjectManagementNum() {
        return leaderProjectManagementNum;
    }

    public void setLeaderProjectManagementNum(String leaderProjectManagementNum) {
        this.leaderProjectManagementNum = leaderProjectManagementNum;
    }

    public String getLeaderUnitResponseNum() {
        return leaderUnitResponseNum;
    }

    public void setLeaderUnitResponseNum(String leaderUnitResponseNum) {
        this.leaderUnitResponseNum = leaderUnitResponseNum;
    }

    public String getLeaderUnitResponseName() {
        return leaderUnitResponseName;
    }

    public void setLeaderUnitResponseName(String leaderUnitResponseName) {
        this.leaderUnitResponseName = leaderUnitResponseName;
    }

    public String getModifierJobNum() {
        return modifierJobNum;
    }

    public void setModifierJobNum(String modifierJobNum) {
        this.modifierJobNum = modifierJobNum;
    }

    public String getModifierName() {
        return modifierName;
    }

    public void setModifierName(String modifierName) {
        this.modifierName = modifierName;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }
}

==> ejc-dxcheck-impl-3.0.0-20240605.085338-26-sources.jar: com/ejianc/business/dxcheck/model/vo/UserVO.java <==
package com.ejianc.business.dxcheck.model.vo;/*author Wyx*/

import cn.hutool.core.date.DateTime;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Getter;
import java.util.Date;

public class UserVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Integer serialNum;//序号
    private String assessmentUnitCode;//考核单位Code
    private String assessmentUnitName;//考核单位名称
    private Long assessmentDeptId; //考核人所在部门ID
    private String assessmentDeptName;//考核人所在部门名称
    private String assessorJobNum;//考核人员工号
    private String assessorName;//考核人员

    private String assessorPhone;//考核人员电话
    private String leaderInfoDepartmentName;//信息化部门领导
    private String leaderInfoDepartmentNum;//信息化部门领导工号
    private String leaderInfoDepartmentPhone;//信息化部门领导电话
    private String leaderProjectManagementName;//项目分管领导
    private String leaderProjectManagementNum;//项目分管领导工号

    private String leaderProjectManagementPhone;//项目分管领导电话
    private String leaderUnitResponseNum;//单位负责人领导工号
    private String leaderUnitResponseName;//单位负责领导

    private String leaderUnitResponsePhone;//单位负责人领导电话
    private String modifierJobNum;//修改人工号
    private String modifierName;//修改人

    private String modifierPhone;//修改人电话
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date modifyTime;//修改时间

    public Long getAssessmentDeptId() {
        return assessmentDeptId;
    }

    public void setAssessmentDeptId(Long assessmentDeptId) {
        this.assessmentDeptId = assessmentDeptId;
    }

    public String getAssessmentDeptName() {
        return assessmentDeptName;
    }

    public void setAssessmentDeptName(String assessmentDeptName) {
        this.assessmentDeptName = assessmentDeptName;
    }

    public void setAssessorPhone(String assessorPhone) {
        this.assessorPhone = assessorPhone;
    }

    public String getAssessorPhone() {
        return assessorPhone;
    }


    public String getLeaderInfoDepartmentPhone() {
        return leaderInfoDepartmentPhone;
    }

    public void setLeaderInfoDepartmentPhone(String leaderInfoDepartmentPhone) {
        this.leaderInfoDepartmentPhone = leaderInfoDepartmentPhone;
    }

    public String getLeaderProjectManagementPhone() {
        return leaderProjectManagementPhone;
    }

    public void setLeaderProjectManagementPhone(String leaderProjectManagementPhone) {
        this.leaderProjectManagementPhone = leaderProjectManagementPhone;
    }

    public String getLeaderUnitResponsePhone() {
        return leaderUnitResponsePhone;
    }

    public void setLeaderUnitResponsePhone(String leaderUnitResponsePhone) {
        this.leaderUnitResponsePhone = leaderUnitResponsePhone;
    }

    public String getModifierPhone() {
        return modifierPhone;
    }

    public void setModifierPhone(String modifierPhone) {
        this.modifierPhone = modifierPhone;
    }


    public Integer getSerialNum() {
        return serialNum;
    }

    public void setSerialNum(Integer serialNum) {
        this.serialNum = serialNum;
    }

    public String getAssessmentUnitCode() {
        return assessmentUnitCode;
    }

    public void setAssessmentUnitCode(String assessmentUnitCode) {
        this.assessmentUnitCode = assessmentUnitCode;
    }

    public String getAssessmentUnitName() {
        return assessmentUnitName;
    }

    public void setAssessmentUnitName(String assessmentUnitName) {
        this.assessmentUnitName = assessmentUnitName;
    }

    public String getAssessorJobNum() {
        return assessorJobNum;
    }

    public void setAssessorJobNum(String assessorJobNum) {
        this.assessorJobNum = assessorJobNum;
    }

    public String getAssessorName() {
        return assessorName;
    }

    public void setAssessorName(String assessorName) {
        this.assessorName = assessorName;
    }

    public String getLeaderInfoDepartmentName() {
        return leaderInfoDepartmentName;
    }

    public void setLeaderInfoDepartmentName(String leaderInfoDepartmentName) {
        this.leaderInfoDepartmentName = leaderInfoDepartmentName;
    }

    public String getLeaderInfoDepartmentNum() {
        return leaderInfoDepartmentNum;
    }

    public void setLeaderInfoDepartmentNum(String leaderInfoDepartmentNum) {
        this.leaderInfoDepartmentNum = leaderInfoDepartmentNum;
    }

    public String getLeaderProjectManagementName() {
        return leaderProjectManagementName;
    }

    public void setLeaderProjectManagementName(String leaderProjectManagementName) {
        this.leaderProjectManagementName = leaderProjectManagementName;
    }

    public String getLeaderProjectManagementNum() {
        return leaderProjectManagementNum;
    }

    public void setLeaderProjectManagementNum(String leaderProjectManagementNum) {
        this.leaderProjectManagementNum = leaderProjectManagementNum;
    }

    public String getLeaderUnitResponseNum() {
        return leaderUnitResponseNum;
    }

    public void setLeaderUnitResponseNum(String leaderUnitResponseNum) {
        this.leaderUnitResponseNum = leaderUnitResponseNum;
    }

    public String getLeaderUnitResponseName() {
        return leaderUnitResponseName;
    }

    public void setLeaderUnitResponseName(String leaderUnitResponseName) {
        this.leaderUnitResponseName = leaderUnitResponseName;
    }

    public String getModifierJobNum() {
        return modifierJobNum;
    }

    public void setModifierJobNum(String modifierJobNum) {
        this.modifierJobNum = modifierJobNum;
    }

    public String getModifierName() {
        return modifierName;
    }

    public void setModifierName(String modifierName) {
        this.modifierName = modifierName;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }
}
